@@ -11,7 +11,7 @@ use MIME::Base64;
 
 #use AutoLoader qw(AUTOLOAD);
 
-our $VERSION = '1.4.6';
+our $VERSION = '1.9.1';
 
 # Set here all the names of functions that must be available in Safe objects.
 # Not that only functions, not methods, can be written here
@@ -132,7 +132,7 @@ sub basic {
     $login    = &unicode2iso($login);
     $password = &unicode2iso($password);
 
-    return "Basic " . encode_base64( $login . ":" . $password );
+    return "Basic " . encode_base64( $login . ":" . $password, '' );
 }
 
 ## @function string unicode2iso(string string)
